import os, sys, shutil, tempfile, tempfile_compat
import xml.dom
from subproc import CmdLine
import split_files, streaming_extractor, plesk_config, log
import execution_result
import gzip_stream
from ReadLineAdapter import ReadLineAdapter


def get_tmp_directory():
    return plesk_config.get("PRODUCT_ROOT_D") + "/tmp"


def get_deployer():
    return plesk_config.get("PRODUCT_ROOT_D") + "/admin/sbin/deployer"


def get_dump_file_name():
    return "dump.xml"


def get_converted_dump_file_name():
    return "dump-plesk.xml"


def usage():
    print "Usage: backup-info <backup-file-name>"


def main():
    if len(sys.argv) != 2:
        usage()
        sys.exit(1)

    backup_file = sys.argv[1].decode("UTF-8")

    tempdir = tempfile.mktemp()
    os.mkdir(tempdir)

    log.initLog("backup_info", tempdir)
    try:
        try:
            backupParts = split_files.findParts(backup_file)
            backup_cat_cmd = split_files.open(backupParts)

            if gzip_stream.isGzipped(backup_file):
                backup_stream = gzip_stream.GzipReadStream(backup_cat_cmd.stdout)
                backup_stream = ReadLineAdapter(backup_stream)
            else:
                backup_stream = backup_cat_cmd.stdout

            dump_file_name = os.path.join(tempdir, "dump-plesk.xml")
            se = streaming_extractor.StreamingExtractor(backup_stream, tempdir, dump_file_name)

            cmd = CmdLine(get_deployer())
            cmd.arg("--session-path=" + tempdir)
            cmd.arg("--get-accounts")
            res =  cmd.spawn()

            result_file_name = os.path.join(tempdir, "migration.result")
            er = execution_result.ExecutionResult()
            er.build(xml.dom.minidom.parse(result_file_name).childNodes[0])

            if er.getStatus() != 'success':
                if len(er.getMessage()) > 0:
                    sys.stdout.write(("Error during parsing backup description: " \
                                     + er.getMessage()[0].getText() + "\n").encode("UTF-8"))
                else:
                    sys.stdout.write("Unknown error during parsing backup description\n")

            print res.stdout
        except Exception, e:
            try:
                s = e.__unicode__().encode("UTF-8")
            except AttributeError:
                s = e.__str__()
            sys.stdout.write(s + "\n")
            sys.exit(1)
    finally:
        shutil.rmtree(tempdir)


if __name__ == '__main__':
    main()
